# -*- coding: utf-8 -*-
# Licensed under a 3-clause BSD style license, see LICENSE.
"""
Utility methods to print system info and org packages info, for debugging.

Heavily inspired from :func:`sklearn.show_versions`.
"""

import platform
import sys
import importlib.metadata


scipy_deps = ["setuptools", "pip", "numpy", "scipy", "pandas", "matplotlib"]


skhep_deps = [
    "awkward",
    "boost_histogram",
    "decaylanguage",
    "hepstats",
    "hepunits",
    "hist",
    "histoprint",
    "iminuit",
    "mplhep",
    "particle",
    "pylhe",
    "resample",
    "scikit-hep",
    "uproot",
    "vector",
]


def _get_sys_info():
    """
    Get system information.

    Return
    ------
    sys_info : dict
        System and Python version information.
    """
    python = sys.version.replace("\n", " ")

    blob = [
        ("python", python),
        ("executable", sys.executable),
        ("machine", platform.platform()),
    ]

    return dict(blob)


def _get_deps_info(pkgs_list):
    """
    Get the installed versions of a list of packages.

    Returns
    -------
    deps_info: dict
        Version information on the input list of libraries.

    """
    deps_info = {}

    for modname in pkgs_list:
        try:
            deps_info[modname] = importlib.metadata.version(modname)
        except ModuleNotFoundError:
            deps_info[modname] = None

    return deps_info


def show_versions():
    """
    Overview of the installed versions of main dependencies on the
    Python scientific ecosystem packages and on the Scikit-HEP packages.
    """

    sys_info = _get_sys_info()
    deps_info = _get_deps_info(scipy_deps)
    skhep_deps_info = _get_deps_info(skhep_deps)

    print("\nSystem:")
    for k, stat in sys_info.items():
        print("{k:>10}: {stat}".format(k=k, stat=stat))

    print("\nPython dependencies:")
    for k, stat in deps_info.items():
        print("{k:>10}: {stat}".format(k=k, stat=stat))

    print("\nScikit-HEP package version and dependencies:")
    for k, stat in skhep_deps_info.items():
        print("{k:>15}: {stat}".format(k=k, stat=stat))



# -*- coding: utf-8 -*-
# Licensed under a 3-clause BSD style license, see LICENSE.
"""
A community-driven and oriented Python software project for High Energy Physics.
"""

from __future__ import absolute_import

from ._show_versions import show_versions

from ._version import __version__


__all__ = [
    "banner",
    "project_url",
    "project_url_GitHub",
    "project_url_PyPI",
    "show_versions",
    "__version__",
]


# -----------------------------------------------------------------------------
# Project and package info
# -----------------------------------------------------------------------------

project_url = "http://scikit-hep.org"
project_url_GitHub = "https://github.com/scikit-hep/scikit-hep"
project_url_PyPI = "https://pypi.python.org/pypi/scikit-hep"

__doc__ = __doc__.format(__version__)

banner = __doc__
